=========================
Conda for data scientists
=========================

Conda is useful for any packaging process but it stands out from other
package and environment management systems through its utility for data
science.

Conda’s benefits include:

* Providing prebuilt packages which avoid the need to deal with compilers or
  figuring out how to set up a specific tool.
* Managing one-step installation of tools that
  are more challenging to install (such as TensorFlow or IRAF).
* Allowing you to provide your environment to other people across different
  platforms, which supports the reproducibility of research workflows.
* Allowing the use of other package management tools, such as pip, inside
  conda environments where a library or tools are not already packaged for
  conda.
* Providing commonly used data science libraries and tools, such as R, NumPy,
  SciPy, and TensorFlow. These are built using optimized, hardware-specific
  libraries (such as Intel’s MKL or NVIDIA’s CUDA) which speed up performance
  without code changes.

`Read more about how conda supports data scientists
<https://kaust-vislab.github.io/introduction-to-conda-for-data-scientists>`_.
